"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.vdb_groups_api import VDBGroupsApi  # noqa: E501


class TestVDBGroupsApi(unittest.TestCase):
    """VDBGroupsApi unit test stubs"""

    def setUp(self):
        self.api = VDBGroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_vdb_group(self):
        """Test case for create_vdb_group

        Create a new VDBGroup.  # noqa: E501
        """
        pass

    def test_delete_vdb_group(self):
        """Test case for delete_vdb_group

        Delete a VDBGoup.  # noqa: E501
        """
        pass

    def test_get_bookmarks_by_vdb_group(self):
        """Test case for get_bookmarks_by_vdb_group

        List bookmarks compatible with this VDB Group.  # noqa: E501
        """
        pass

    def test_get_vdb_group(self):
        """Test case for get_vdb_group

        Get a VDBGroup by name.  # noqa: E501
        """
        pass

    def test_get_vdb_groups(self):
        """Test case for get_vdb_groups

        List all VDBGroups.  # noqa: E501
        """
        pass

    def test_provision_vdb_group_from_bookmark(self):
        """Test case for provision_vdb_group_from_bookmark

        Provision a new VDB Group from a Bookmark.  # noqa: E501
        """
        pass

    def test_refresh_vdb_group(self):
        """Test case for refresh_vdb_group

        Refresh a VDBGroup.  # noqa: E501
        """
        pass

    def test_rollback_vdb_group(self):
        """Test case for rollback_vdb_group

        Rollback a VDBGroup.  # noqa: E501
        """
        pass

    def test_search_vdb_groups(self):
        """Test case for search_vdb_groups

        Search for VDB Groups.  # noqa: E501
        """
        pass

    def test_update_vdb_group_by_id(self):
        """Test case for update_vdb_group_by_id

        Update values of a VDB group.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
