"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.management_api import ManagementApi  # noqa: E501


class TestManagementApi(unittest.TestCase):
    """ManagementApi unit test stubs"""

    def setUp(self):
        self.api = ManagementApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_engine_tags(self):
        """Test case for create_engine_tags

        Create tags for a engine.  # noqa: E501
        """
        pass

    def test_create_hashicorp_vault(self):
        """Test case for create_hashicorp_vault

        Configure a new Hashicorp Vault  # noqa: E501
        """
        pass

    def test_delete_engine_tags(self):
        """Test case for delete_engine_tags

        Delete tags for an Engine.  # noqa: E501
        """
        pass

    def test_delete_hashicorp_vault(self):
        """Test case for delete_hashicorp_vault

        Delete a Hashicorp vault by id  # noqa: E501
        """
        pass

    def test_get_engine_tags(self):
        """Test case for get_engine_tags

        Get tags for a Engine.  # noqa: E501
        """
        pass

    def test_get_hashicorp_vault(self):
        """Test case for get_hashicorp_vault

        Get a Hashicorp vault by id  # noqa: E501
        """
        pass

    def test_get_hashicorp_vaults(self):
        """Test case for get_hashicorp_vaults

        Returns a list of configured Hashicorp vaults.  # noqa: E501
        """
        pass

    def test_get_registered_engine(self):
        """Test case for get_registered_engine

        Returns a registered engine by ID.  # noqa: E501
        """
        pass

    def test_get_registered_engines(self):
        """Test case for get_registered_engines

        Returns a list of registered engines.  # noqa: E501
        """
        pass

    def test_get_smtp_config(self):
        """Test case for get_smtp_config

        Returns the SMTP configuration  # noqa: E501
        """
        pass

    def test_register_engine(self):
        """Test case for register_engine

        Register an engine.  # noqa: E501
        """
        pass

    def test_search_engines(self):
        """Test case for search_engines

        Search for engines.  # noqa: E501
        """
        pass

    def test_unregister_engine(self):
        """Test case for unregister_engine

        Unregister an engine.  # noqa: E501
        """
        pass

    def test_update_registered_engine(self):
        """Test case for update_registered_engine

        Update a registered engine.  # noqa: E501
        """
        pass

    def test_update_smtp_config(self):
        """Test case for update_smtp_config

        Update SMTP Config.  # noqa: E501
        """
        pass

    def test_validate_smtp_config(self):
        """Test case for validate_smtp_config

        Validate SMTP Config.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
