"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.delete_vdb_parameters import DeleteVDBParameters
from delphix.api.gateway.model.delete_vdb_response import DeleteVDBResponse
from delphix.api.gateway.model.disable_vdb_parameters import DisableVDBParameters
from delphix.api.gateway.model.disable_vdb_response import DisableVDBResponse
from delphix.api.gateway.model.enable_vdb_parameters import EnableVDBParameters
from delphix.api.gateway.model.enable_vdb_response import EnableVDBResponse
from delphix.api.gateway.model.list_snapshots_response import ListSnapshotsResponse
from delphix.api.gateway.model.list_vdbs_response import ListVDBsResponse
from delphix.api.gateway.model.provision_vdbby_snapshot_parameters import ProvisionVDBBySnapshotParameters
from delphix.api.gateway.model.provision_vdbby_timestamp_parameters import ProvisionVDBByTimestampParameters
from delphix.api.gateway.model.provision_vdb_from_bookmark_parameters import ProvisionVDBFromBookmarkParameters
from delphix.api.gateway.model.provision_vdb_response import ProvisionVDBResponse
from delphix.api.gateway.model.refresh_vdbby_snapshot_parameters import RefreshVDBBySnapshotParameters
from delphix.api.gateway.model.refresh_vdbby_snapshot_response import RefreshVDBBySnapshotResponse
from delphix.api.gateway.model.refresh_vdbby_timestamp_parameters import RefreshVDBByTimestampParameters
from delphix.api.gateway.model.refresh_vdbby_timestamp_response import RefreshVDBByTimestampResponse
from delphix.api.gateway.model.refresh_vdb_from_bookmark_parameters import RefreshVDBFromBookmarkParameters
from delphix.api.gateway.model.refresh_vdb_from_bookmark_response import RefreshVDBFromBookmarkResponse
from delphix.api.gateway.model.rollback_vdbby_snapshot_parameters import RollbackVDBBySnapshotParameters
from delphix.api.gateway.model.rollback_vdbby_snapshot_response import RollbackVDBBySnapshotResponse
from delphix.api.gateway.model.rollback_vdbby_timestamp_parameters import RollbackVDBByTimestampParameters
from delphix.api.gateway.model.rollback_vdbby_timestamp_response import RollbackVDBByTimestampResponse
from delphix.api.gateway.model.rollback_vdb_from_bookmark_parameters import RollbackVDBFromBookmarkParameters
from delphix.api.gateway.model.rollback_vdb_from_bookmark_response import RollbackVDBFromBookmarkResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_vdbs_response import SearchVDBsResponse
from delphix.api.gateway.model.snapshot_vdb_response import SnapshotVDBResponse
from delphix.api.gateway.model.start_vdb_response import StartVDBResponse
from delphix.api.gateway.model.stop_vdb_response import StopVDBResponse
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
from delphix.api.gateway.model.update_vdb_parameters import UpdateVDBParameters
from delphix.api.gateway.model.update_vdb_response import UpdateVDBResponse
from delphix.api.gateway.model.vdb import VDB


class VDBsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_vdb_tags(
            self,
            vdb_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_vdb_tags(vdb_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.
                tags_request (TagsRequest): Tags information for VDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_vdb_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/tags',
                'operation_id': 'create_vdb_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'tags_request',
                ],
                'required': [
                    'vdb_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_vdb_tags
        )

        def __delete_vdb(
            self,
            vdb_id,
            **kwargs
        ):
            """Delete a VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_vdb(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                delete_vdb_parameters (DeleteVDBParameters): The parameters to delete a VDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DeleteVDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.delete_vdb = _Endpoint(
            settings={
                'response_type': (DeleteVDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/delete',
                'operation_id': 'delete_vdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'delete_vdb_parameters',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'delete_vdb_parameters':
                        (DeleteVDBParameters,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'delete_vdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_vdb
        )

        def __delete_vdb_tags(
            self,
            vdb_id,
            **kwargs
        ):
            """Delete tags for a VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_vdb_tags(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.delete_vdb_tags = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/tags/delete',
                'operation_id': 'delete_vdb_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'delete_tag',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_vdb_tags
        )

        def __disable_vdb(
            self,
            vdb_id,
            **kwargs
        ):
            """Disable a VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.disable_vdb(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                disable_vdb_parameters (DisableVDBParameters): The parameters to disable a VDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DisableVDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.disable_vdb = _Endpoint(
            settings={
                'response_type': (DisableVDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/disable',
                'operation_id': 'disable_vdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'disable_vdb_parameters',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'disable_vdb_parameters':
                        (DisableVDBParameters,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'disable_vdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__disable_vdb
        )

        def __enable_vdb(
            self,
            vdb_id,
            **kwargs
        ):
            """Enable a VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.enable_vdb(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                enable_vdb_parameters (EnableVDBParameters): The parameters to enable a VDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                EnableVDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.enable_vdb = _Endpoint(
            settings={
                'response_type': (EnableVDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/enable',
                'operation_id': 'enable_vdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'enable_vdb_parameters',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'enable_vdb_parameters':
                        (EnableVDBParameters,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'enable_vdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__enable_vdb
        )

        def __get_tags_vdb(
            self,
            vdb_id,
            **kwargs
        ):
            """Get tags for a VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_tags_vdb(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.get_tags_vdb = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/tags',
                'operation_id': 'get_tags_vdb',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_tags_vdb
        )

        def __get_vdb_by_id(
            self,
            vdb_id,
            **kwargs
        ):
            """Get a VDB by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_vdb_by_id(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                VDB
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.get_vdb_by_id = _Endpoint(
            settings={
                'response_type': (VDB,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}',
                'operation_id': 'get_vdb_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_vdb_by_id
        )

        def __get_vdb_snapshots(
            self,
            vdb_id,
            **kwargs
        ):
            """List Snapshots for a VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_vdb_snapshots(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListSnapshotsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.get_vdb_snapshots = _Endpoint(
            settings={
                'response_type': (ListSnapshotsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/snapshots',
                'operation_id': 'get_vdb_snapshots',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'limit',
                    'cursor',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                    'limit': 'limit',
                    'cursor': 'cursor',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'limit': 'query',
                    'cursor': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_vdb_snapshots
        )

        def __get_vdbs(
            self,
            **kwargs
        ):
            """List all vdbs.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_vdbs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListVDBsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_vdbs = _Endpoint(
            settings={
                'response_type': (ListVDBsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs',
                'operation_id': 'get_vdbs',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "DATABASE_TYPE": "database_type",
                        "-DATABASE_TYPE": "-database_type",
                        "NAME": "name",
                        "-NAME": "-name",
                        "DATABASE_VERSION": "database_version",
                        "-DATABASE_VERSION": "-database_version",
                        "SIZE": "size",
                        "-SIZE": "-size",
                        "ENGINE_ID": "engine_id",
                        "-ENGINE_ID": "-engine_id",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "ENVIRONMENT_ID": "environment_id",
                        "-ENVIRONMENT_ID": "-environment_id",
                        "IP_ADDRESS": "ip_address",
                        "-IP_ADDRESS": "-ip_address",
                        "FQDN": "fqdn",
                        "-FQDN": "-fqdn",
                        "PARENT_ID": "parent_id",
                        "-PARENT_ID": "-parent_id",
                        "GROUP_NAME": "group_name",
                        "-GROUP_NAME": "-group_name",
                        "CREATION_DATE": "creation_date",
                        "-CREATION_DATE": "-creation_date"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_vdbs
        )

        def __provision_vdb_by_snapshot(
            self,
            provision_vdbby_snapshot_parameters,
            **kwargs
        ):
            """Provision a new VDB by snapshot.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.provision_vdb_by_snapshot(provision_vdbby_snapshot_parameters, async_req=True)
            >>> result = thread.get()

            Args:
                provision_vdbby_snapshot_parameters (ProvisionVDBBySnapshotParameters): The parameters to provision a VDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ProvisionVDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['provision_vdbby_snapshot_parameters'] = \
                provision_vdbby_snapshot_parameters
            return self.call_with_http_info(**kwargs)

        self.provision_vdb_by_snapshot = _Endpoint(
            settings={
                'response_type': (ProvisionVDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/provision_by_snapshot',
                'operation_id': 'provision_vdb_by_snapshot',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'provision_vdbby_snapshot_parameters',
                ],
                'required': [
                    'provision_vdbby_snapshot_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'provision_vdbby_snapshot_parameters':
                        (ProvisionVDBBySnapshotParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'provision_vdbby_snapshot_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__provision_vdb_by_snapshot
        )

        def __provision_vdb_by_timestamp(
            self,
            provision_vdbby_timestamp_parameters,
            **kwargs
        ):
            """Provision a new VDB by timestamp.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.provision_vdb_by_timestamp(provision_vdbby_timestamp_parameters, async_req=True)
            >>> result = thread.get()

            Args:
                provision_vdbby_timestamp_parameters (ProvisionVDBByTimestampParameters): The parameters to provision a VDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ProvisionVDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['provision_vdbby_timestamp_parameters'] = \
                provision_vdbby_timestamp_parameters
            return self.call_with_http_info(**kwargs)

        self.provision_vdb_by_timestamp = _Endpoint(
            settings={
                'response_type': (ProvisionVDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/provision_by_timestamp',
                'operation_id': 'provision_vdb_by_timestamp',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'provision_vdbby_timestamp_parameters',
                ],
                'required': [
                    'provision_vdbby_timestamp_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'provision_vdbby_timestamp_parameters':
                        (ProvisionVDBByTimestampParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'provision_vdbby_timestamp_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__provision_vdb_by_timestamp
        )

        def __provision_vdb_from_bookmark(
            self,
            provision_vdb_from_bookmark_parameters,
            **kwargs
        ):
            """Provision a new VDB from a bookmark with a single VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.provision_vdb_from_bookmark(provision_vdb_from_bookmark_parameters, async_req=True)
            >>> result = thread.get()

            Args:
                provision_vdb_from_bookmark_parameters (ProvisionVDBFromBookmarkParameters): The parameters to provision a VDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ProvisionVDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['provision_vdb_from_bookmark_parameters'] = \
                provision_vdb_from_bookmark_parameters
            return self.call_with_http_info(**kwargs)

        self.provision_vdb_from_bookmark = _Endpoint(
            settings={
                'response_type': (ProvisionVDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/provision_from_bookmark',
                'operation_id': 'provision_vdb_from_bookmark',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'provision_vdb_from_bookmark_parameters',
                ],
                'required': [
                    'provision_vdb_from_bookmark_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'provision_vdb_from_bookmark_parameters':
                        (ProvisionVDBFromBookmarkParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'provision_vdb_from_bookmark_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__provision_vdb_from_bookmark
        )

        def __refresh_vdb_by_snapshot(
            self,
            vdb_id,
            **kwargs
        ):
            """Refresh a VDB by snapshot.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.refresh_vdb_by_snapshot(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                refresh_vdbby_snapshot_parameters (RefreshVDBBySnapshotParameters): The parameters to refresh a VDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RefreshVDBBySnapshotResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.refresh_vdb_by_snapshot = _Endpoint(
            settings={
                'response_type': (RefreshVDBBySnapshotResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/refresh_by_snapshot',
                'operation_id': 'refresh_vdb_by_snapshot',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'refresh_vdbby_snapshot_parameters',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'refresh_vdbby_snapshot_parameters':
                        (RefreshVDBBySnapshotParameters,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'refresh_vdbby_snapshot_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__refresh_vdb_by_snapshot
        )

        def __refresh_vdb_by_timestamp(
            self,
            vdb_id,
            **kwargs
        ):
            """Refresh a VDB by timestamp.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.refresh_vdb_by_timestamp(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                refresh_vdbby_timestamp_parameters (RefreshVDBByTimestampParameters): The parameters to refresh a VDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RefreshVDBByTimestampResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.refresh_vdb_by_timestamp = _Endpoint(
            settings={
                'response_type': (RefreshVDBByTimestampResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/refresh_by_timestamp',
                'operation_id': 'refresh_vdb_by_timestamp',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'refresh_vdbby_timestamp_parameters',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'refresh_vdbby_timestamp_parameters':
                        (RefreshVDBByTimestampParameters,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'refresh_vdbby_timestamp_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__refresh_vdb_by_timestamp
        )

        def __refresh_vdb_from_bookmark(
            self,
            vdb_id,
            **kwargs
        ):
            """Refresh a VDB from bookmark with a single VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.refresh_vdb_from_bookmark(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                refresh_vdb_from_bookmark_parameters (RefreshVDBFromBookmarkParameters): The parameters to refresh a VDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RefreshVDBFromBookmarkResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.refresh_vdb_from_bookmark = _Endpoint(
            settings={
                'response_type': (RefreshVDBFromBookmarkResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/refresh_from_bookmark',
                'operation_id': 'refresh_vdb_from_bookmark',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'refresh_vdb_from_bookmark_parameters',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'refresh_vdb_from_bookmark_parameters':
                        (RefreshVDBFromBookmarkParameters,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'refresh_vdb_from_bookmark_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__refresh_vdb_from_bookmark
        )

        def __rollback_vdb_by_snapshot(
            self,
            vdb_id,
            **kwargs
        ):
            """Rollback a VDB by snapshot.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.rollback_vdb_by_snapshot(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                rollback_vdbby_snapshot_parameters (RollbackVDBBySnapshotParameters): The parameters to rollback a VDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RollbackVDBBySnapshotResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.rollback_vdb_by_snapshot = _Endpoint(
            settings={
                'response_type': (RollbackVDBBySnapshotResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/rollback_by_snapshot',
                'operation_id': 'rollback_vdb_by_snapshot',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'rollback_vdbby_snapshot_parameters',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'rollback_vdbby_snapshot_parameters':
                        (RollbackVDBBySnapshotParameters,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'rollback_vdbby_snapshot_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__rollback_vdb_by_snapshot
        )

        def __rollback_vdb_by_timestamp(
            self,
            vdb_id,
            **kwargs
        ):
            """Rollback a VDB by timestamp.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.rollback_vdb_by_timestamp(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                rollback_vdbby_timestamp_parameters (RollbackVDBByTimestampParameters): The parameters to rollback a VDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RollbackVDBByTimestampResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.rollback_vdb_by_timestamp = _Endpoint(
            settings={
                'response_type': (RollbackVDBByTimestampResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/rollback_by_timestamp',
                'operation_id': 'rollback_vdb_by_timestamp',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'rollback_vdbby_timestamp_parameters',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'rollback_vdbby_timestamp_parameters':
                        (RollbackVDBByTimestampParameters,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'rollback_vdbby_timestamp_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__rollback_vdb_by_timestamp
        )

        def __rollback_vdb_from_bookmark(
            self,
            vdb_id,
            **kwargs
        ):
            """Rollback a VDB from a bookmark with only the same VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.rollback_vdb_from_bookmark(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                rollback_vdb_from_bookmark_parameters (RollbackVDBFromBookmarkParameters): The parameters to rollback a VDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                RollbackVDBFromBookmarkResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.rollback_vdb_from_bookmark = _Endpoint(
            settings={
                'response_type': (RollbackVDBFromBookmarkResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/rollback_from_bookmark',
                'operation_id': 'rollback_vdb_from_bookmark',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'rollback_vdb_from_bookmark_parameters',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'rollback_vdb_from_bookmark_parameters':
                        (RollbackVDBFromBookmarkParameters,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'rollback_vdb_from_bookmark_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__rollback_vdb_from_bookmark
        )

        def __search_vdbs(
            self,
            **kwargs
        ):
            """Search for VDBs.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_vdbs(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchVDBsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_vdbs = _Endpoint(
            settings={
                'response_type': (SearchVDBsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/search',
                'operation_id': 'search_vdbs',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "DATABASE_TYPE": "database_type",
                        "-DATABASE_TYPE": "-database_type",
                        "NAME": "name",
                        "-NAME": "-name",
                        "DATABASE_VERSION": "database_version",
                        "-DATABASE_VERSION": "-database_version",
                        "SIZE": "size",
                        "-SIZE": "-size",
                        "ENGINE_ID": "engine_id",
                        "-ENGINE_ID": "-engine_id",
                        "STATUS": "status",
                        "-STATUS": "-status",
                        "ENVIRONMENT_ID": "environment_id",
                        "-ENVIRONMENT_ID": "-environment_id",
                        "IP_ADDRESS": "ip_address",
                        "-IP_ADDRESS": "-ip_address",
                        "FQDN": "fqdn",
                        "-FQDN": "-fqdn",
                        "PARENT_ID": "parent_id",
                        "-PARENT_ID": "-parent_id",
                        "GROUP_NAME": "group_name",
                        "-GROUP_NAME": "-group_name",
                        "CREATION_DATE": "creation_date",
                        "-CREATION_DATE": "-creation_date"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_vdbs
        )

        def __snapshot_vdb(
            self,
            vdb_id,
            **kwargs
        ):
            """Snapshot a VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.snapshot_vdb(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SnapshotVDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.snapshot_vdb = _Endpoint(
            settings={
                'response_type': (SnapshotVDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/snapshots',
                'operation_id': 'snapshot_vdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__snapshot_vdb
        )

        def __start_vdb(
            self,
            vdb_id,
            **kwargs
        ):
            """Start a VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.start_vdb(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                StartVDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.start_vdb = _Endpoint(
            settings={
                'response_type': (StartVDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/start',
                'operation_id': 'start_vdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__start_vdb
        )

        def __stop_vdb(
            self,
            vdb_id,
            **kwargs
        ):
            """Stop a VDB.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.stop_vdb(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                StopVDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.stop_vdb = _Endpoint(
            settings={
                'response_type': (StopVDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}/stop',
                'operation_id': 'stop_vdb',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__stop_vdb
        )

        def __update_vdb_by_id(
            self,
            vdb_id,
            **kwargs
        ):
            """Update values of a VDB  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_vdb_by_id(vdb_id, async_req=True)
            >>> result = thread.get()

            Args:
                vdb_id (str): The ID of the VDB.

            Keyword Args:
                update_vdb_parameters (UpdateVDBParameters): The new data to update a VDB.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdateVDBResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['vdb_id'] = \
                vdb_id
            return self.call_with_http_info(**kwargs)

        self.update_vdb_by_id = _Endpoint(
            settings={
                'response_type': (UpdateVDBResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/vdbs/{vdbId}',
                'operation_id': 'update_vdb_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'vdb_id',
                    'update_vdb_parameters',
                ],
                'required': [
                    'vdb_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'vdb_id',
                ]
            },
            root_map={
                'validations': {
                    ('vdb_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'vdb_id':
                        (str,),
                    'update_vdb_parameters':
                        (UpdateVDBParameters,),
                },
                'attribute_map': {
                    'vdb_id': 'vdbId',
                },
                'location_map': {
                    'vdb_id': 'path',
                    'update_vdb_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_vdb_by_id
        )
