"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.api_clients_api import ApiClientsApi  # noqa: E501


class TestApiClientsApi(unittest.TestCase):
    """ApiClientsApi unit test stubs"""

    def setUp(self):
        self.api = ApiClientsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_api_client(self):
        """Test case for create_api_client

        Create a new API Client.   # noqa: E501
        """
        pass

    def test_delete_api_client(self):
        """Test case for delete_api_client

        Delete an API client  # noqa: E501
        """
        pass

    def test_get_api_client(self):
        """Test case for get_api_client

        Get an API client by id  # noqa: E501
        """
        pass

    def test_get_api_clients(self):
        """Test case for get_api_clients

        Returns a list of API clients.  # noqa: E501
        """
        pass

    def test_update_api_client(self):
        """Test case for update_api_client

        Update an Api client.   # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
